<?php
/**
 * @file mod_roomReservationPage.inc
 * A generic page class
 * @author Roland Hieber (roland.hieber@wilhelm-gym.net)
 * @date 24.06.2008
 * 
 * Copyright © 2007 Roland Hieber
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

require_once("mod_room-reservation/mod_roomReservationConfig.inc");

/** @todo document */
abstract class mod_roomReservationPage {
  /** (mod_roomReservationConfig) Reference to the configuration object */
  protected $oCfg;
  /** (string) Page title for PageBlue() */
  protected $strTitle;
  /** (string) Title icon for PageBlue() */
  protected $strIcon;
  
  /***************************************************************************/
  /**
   * @name Constructor
   * @{
   * Constructor
   * @param $oCfg (reference to mod_roomReservationConfig) Reference to the
   *  configuration
   * @return mod_roomReservationPage
   */
  function __construct(mod_roomReservationConfig &$oCfg) {
    $this->oCfg = $oCfg;
    
    $this->processRequestVariables();
  }

  /***************************************************************************/
  /**
   * @}
   * @name Initialization
   * @{
   */
  
  /**
   * Process the REQUEST variables and preset the some variables. Override
   * this function to process GET and POST parameters.
   * @return void
   */
  protected function processRequestVariables() { }

  /***************************************************************************/
  /**
   * @}
   * @name Access to attributes
   * @{
   */
  
  /**
   * Set the page title
   * @param $str (string)
   * @return void
   */
  public function setTitle($str) { $this->strTitle = $str; }
  
  /**
   * Set the title icon
   * @param $str (string)
   * @return void
   */
  public function setIcon($str) { $this->strIcon = $str; }
  
  /**
   * Get the page title
   * @return string
   */
  public function getTitle() { return $this->strTitle; }

  /**
   * Get the title icon
   * @return string
   */
  public function getIcon() { return $this->strIcon; }

  /***************************************************************************/
  /**
   * @}
   * @name Output
   * @{
   */

  /**
   * Show the beginning of the page.
   * @return void
   */
  protected function beginShow() {
    html_header("<style type='text/css'>\n".rrGetCss()."\n</style>\n");
    PageBlue(q($this->getTitle()), $this->getIcon());
    
    // print error messages from the configuration
    if($s = trim($this->oCfg->getMessages()) != "") {
      printf("<p class='err'>%s</p>\n", nl2br(q($s)));
    }
  }
  
  /**
   * Show the beginning of the page. Override this function to print your 
   * HTML code.
   * @return void
   */
  protected abstract function doShow();
  
  /**
   * Show the end of the page.
   * @return void
   */
  protected function endShow() {
    _PageBlue();
  }

  /**
   * Show the full page. You don't need to override this function. Instead,
   * override doShow(). 
   * @return void
   */
  public function show() {
    $this->beginShow();
    $this->doShow();
    $this->endShow();
  }

}
?>